.. _user_guide:

=============
User Guide
=============

Welcome to the `k-diagram` User Guide!

While the :doc:`../quickstart` provides a fast runnable example and the
:doc:`../gallery/index` showcases the various plots, this
guide aims to provide a deeper understanding of the concepts behind the
different visualizations and helper functions offered by `k-diagram`.

Here, you'll find explanations of:

* **What** each plot or utility does.
* **Why** specific polar representations or data structures are used.
* **How** to interpret the patterns and features within each diagram.
* **When** to use specific plots and utilities for effective model
  evaluation, uncertainty analysis, and data preparation.

Dive into the topics below to learn more about interpreting and applying
`k-diagram`'s specialized tools to gain richer insights from your
forecasting models and data.

.. toctree::
   :maxdepth: 1
   :caption: Guide Topics:

   uncertainty
   errors
   probabilistic
   comparison
   relationship
   feature_based
   evaluation
   anomaly
   taylor_diagram
   context
   hist
   metric
   forecast_utils
   quantile_utils
   math_utils
   datasets
   case_history

We hope this guide enhances your ability to leverage `k-diagram` for
comprehensive forecast analysis. For detailed function parameters, please
refer to the :doc:`../api`.